import React, { Component } from 'react'

import TopicStore from '../stores/TopicStore'
import QuestionStore, { POPULAR_QUESTIONS } from '../stores/QuestionStore'
import QuestionView from './QuestionView'

export default class PopularQuestions extends Component {
  constructor() {
    super()
    this.state = { questions: [] }
  }

  handleTopic = (state) => {
    const { topic } = this.props

    if (state[topic]) {
      QuestionStore.popular({ topicId: state[topic].id, limit: 5 })
    }
  }

  handleQuestions = (state) => {
    if (state[POPULAR_QUESTIONS]) {
      this.setState({ questions: state[POPULAR_QUESTIONS] })
    }
  }

  componentDidMount() {
    this.unsubscribeQuestion = QuestionStore.subscribe(this.handleQuestions)

    const { topic, limit } = this.props

    if (topic) {
      this.unsubscribeTopic = TopicStore.subscribe(this.handleTopic)
      TopicStore.search(topic)
    } else {
      QuestionStore.popular({ limit: limit })
    }
  }

  componentWillUnmount() {
    if (this.unsubscribeQuestion) {
      this.unsubscribeQuestion()
      this.unsubscribeQuestion = null
    }

    if (this.unsubscribeTopic) {
      this.unsubscribeTopic()
      this.unsubscribeTopic = null
    }
  }

  render() {
    const { questions } = this.state

    return (<div>
      {questions.map(q => {
        return <QuestionView key={q.id} question={q} />
      })}
    </div>)
  }
}
