import React, { Component } from 'react'
import UserView from './UserView'
import AnswerView from './AnswerView'
import QuestionStore from '../stores/QuestionStore'

import styles from '../../styles/QuestionView.css'
import contentStyles from '../../styles/Content.css'

export default class QuestionView extends Component {
  constructor(props) {
    super(props)
    this.state = { question: props.question }
  }

  handleQuestion = (state) => {
    if (state[this.state.question.id]) {
      this.setState({ question: state[this.state.question.id] })
    }
  }

  componentDidMount() {
    this.unsubscribe = QuestionStore.subscribe(this.handleQuestion)
    QuestionStore.get(this.state.question)
  }

  componentWillUnmount() {
    if (this.unsubscribe) {
      this.unsubscribe()
      this.unsubscribe = null
    }
  }

  renderBody() {
    const { question } = this.state

    if (!question.loaded)
      return

    return <div
      className={contentStyles.contentContainer}
      dangerouslySetInnerHTML={{ __html: question.body.content }}
    />
  }

  renderAnswers() {
    const { question } = this.state

    if (!question.loaded)
      return

    return <div>
      {question.answers.map(a => {
        return <AnswerView key={a.id} answer={a} />
      })}
    </div>
  }

  render() {
    const { question } = this.state

    return (<div className={styles.questionsContainer}>
      <div className={styles.questionsHeader}>
        <a className={styles.titleLink} href={question.url}>{question.title}</a>
      </div>
      <div>
        {question.author && <UserView user={question.author}>
          <small>{question.friendlyDateAsked}</small>
        </UserView>}
      </div>
      {this.renderBody()}
      {this.renderAnswers()}
    </div>)
  }
}
