import React, { Component } from 'react'

import QuestionStore, { SEARCH_RESULTS } from '../stores/QuestionStore'
import QuestionView from './QuestionView'

import styles from '../../styles/Search.css'

export default class Search extends Component {
  constructor() {
    super()
    this.state = { searchValue: '', results: [] }
  }

  searchQuestions(query) {
    return () => {
      QuestionStore.search(query)
    }
  }

  handleResults = (state) => {
    if (state[SEARCH_RESULTS]) {
      this.setState({ results: state[SEARCH_RESULTS] })
    }
  }

  componentDidMount() {
    this.unsubscribe = QuestionStore.subscribe(this.handleResults)
  }

  componentWillUnmount() {
    let { searchTimer } = this.state

    if (searchTimer) {
      clearTimeout(searchTimer)
    }

    if (this.unsubscribe) {
      this.unsubscribe()
      this.unsubscribe = null
    }
  }

  renderResults() {
    if (this.state.searchValue === '') {
      return this.props.children
    }

    const { results } = this.state

    if (results.length == 0) {
      return <h4 className={styles.searchNoResults}>No results</h4>
    } else {
      return results.map(q => {
        return <QuestionView question={q} key={q.id} />
      })
    }
  }

  handleSearch = (e) => {
    let { searchTimer } = this.state

    if (searchTimer) {
      clearTimeout(searchTimer)
    }

    const value = e.target.value
    searchTimer = setTimeout(
      this.searchQuestions(value), 300
    )

    this.setState({
      searchValue: value,
      searchTimer: searchTimer
    })
  }

  render() {
    return (<div className={styles.searchContainer}>
      <input
        placeholder="Search questions"
        onChange={this.handleSearch}
        value={this.state.searchValue}
        className={styles.flexBox}
        type="text"
      />
      <div className={styles.flexBox}>
        {this.renderResults()}
      </div>
    </div>)
  }
}
