import React, { Component } from 'react'
import UserStore from '../stores/UserStore'

import styles from '../../styles/UserView.css'

export default class UserView extends Component {
  constructor(props) {
    super(props)

    // default
    this.state = { avatar: 'https://secure.gravatar.com/avatar/?d=mm&f=y&s=48' }
    this.loading = false
  }

  handleAvatar = (state) => {
    if (state[this.props.user.name]) {
      this.setState({ avatar: state[this.props.user.name] })
      this.loading = false
    } else if (!this.loading) {
      UserStore.getAvatar(this.props.user)
      this.loading = true
    }
  }

  componentDidMount() {
    this.unsubscribe = UserStore.subscribe(this.handleAvatar)
  }

  componentWillUnmount() {
    if (this.unsubscribe) {
      this.unsubscribe()
      this.unsubscribe = null
    }
  }

  render() {
    const { user, children } = this.props
    const { avatar } = this.state

    return (<div className={styles.userContainer}>
      <img className={styles.userAvatar} src={avatar} />
      <div className={styles.userInfo}>
        <div>{user.fullName}</div>
        <div>{children}</div>
      </div>
    </div>)
  }
}
