import React, { Component } from 'react'
import querystring from 'querystring'

import AtlassianClient from '../AtlassianClient'
import Question from '../models/Question'
import Store from './Store'

const SEARCH_RESULTS = 'search-results',
  POPULAR_QUESTIONS = 'popular-questions'

class QuestionStore extends Store {
  get(question) {
    AtlassianClient.fetchWiki(`/question/${question.id}`).
      then(data => {
        this.set(question.id, new Question(Object.assign({ loaded: true }, data)))
      }).catch(error => {
        // TODO?
        console.log(error)
      })
  }

  search(query, params = {}) {
    params.type = 'question'

    if (!params.limit || params.limit < 1) {
      params.limit = 10
    }

    params.query = query

    let paramsStr = querystring.stringify(params)

    this.set('search-results', [])

    AtlassianClient.fetchWiki(`/search?${paramsStr}`).
      then(data => data.results.map(q => new Question(q))).
      then(results => this.set('search-results', results)).
      catch(error => console.log(error)) // TODO?
  }

  popular(params = {}) {
    params.filter = 'popular'

    if (!params.limit || params.limit < 1) {
      params.limit = 10
    }

    let paramsStr = querystring.stringify(params)

    AtlassianClient.fetchWiki(`/question?${paramsStr}`).
      then(data => data.map(q => new Question(q))).
      then(questions => this.set('popular-questions', questions)).
      catch(error => console.log(error))
  }
}

const store = new QuestionStore()

export { store as default, SEARCH_RESULTS, POPULAR_QUESTIONS }
